==> jc-1.4.0.tar.gz: soot/grimp/GrimpBody.h <==
// public class soot.grimp.GrimpBody

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 81b257e12c028457 soot_grimp_GrimpBody
// @dep_class a93f9b2adf19105a soot_jimple_StmtBody
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_StmtBody

#include "soot/jimple/StmtBody.h"

#ifndef _JC_soot_grimp_GrimpBody_H_
#define _JC_soot_grimp_GrimpBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_grimp_GrimpBody$sub_refs	_jc_soot_grimp_GrimpBody$sub_refs;
typedef struct _jc_soot_grimp_GrimpBody$sub_nonrefs	_jc_soot_grimp_GrimpBody$sub_nonrefs;
typedef struct _jc_soot_grimp_GrimpBody$refs	_jc_soot_grimp_GrimpBody$refs;
typedef struct _jc_soot_grimp_GrimpBody$nonrefs	_jc_soot_grimp_GrimpBody$nonrefs;
typedef struct _jc_soot_grimp_GrimpBody$object	_jc_soot_grimp_GrimpBody$object;

typedef const struct _jc_soot_grimp_GrimpBody$vmethods	_jc_soot_grimp_GrimpBody$vmethods;
typedef const struct _jc_soot_grimp_GrimpBody$vtable	_jc_soot_grimp_GrimpBody$vtable;
typedef const struct _jc_soot_grimp_GrimpBody$vtype	_jc_soot_grimp_GrimpBody$vtype;

// Constructors
extern void _jc_soot_grimp_GrimpBody$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_grimp_GrimpBody$object *, struct _jc_soot_Body$object *);
extern void _jc_soot_grimp_GrimpBody$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_grimp_GrimpBody$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_GrimpBody$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_GrimpBody$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_GrimpBody$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_GrimpBody$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_GrimpBody$object *);
};

// Vtable
struct _jc_soot_grimp_GrimpBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_Body$vmethods	soot_Body;
	_jc_soot_jimple_StmtBody$vmethods	soot_jimple_StmtBody;
	_jc_soot_grimp_GrimpBody$vmethods	soot_grimp_GrimpBody;
};

// Vtype
struct _jc_soot_grimp_GrimpBody$vtype {
	_jc_type			type;
	_jc_soot_grimp_GrimpBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_GrimpBody$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_GrimpBody$refs {
    _jc_soot_grimp_GrimpBody$sub_refs	soot_grimp_GrimpBody;
    _jc_soot_jimple_StmtBody$sub_refs	soot_jimple_StmtBody;
    _jc_soot_Body$sub_refs	soot_Body;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_GrimpBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_GrimpBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_Body$sub_nonrefs	soot_Body;
    _jc_soot_jimple_StmtBody$sub_nonrefs	soot_jimple_StmtBody;
    _jc_soot_grimp_GrimpBody$sub_nonrefs	soot_grimp_GrimpBody;
};

// Object instance structure
struct _jc_soot_grimp_GrimpBody$object {
	_jc_soot_grimp_GrimpBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_GrimpBody$vtype	*vtype;
	_jc_soot_grimp_GrimpBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_GrimpBody$vtype _jc_soot_grimp_GrimpBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_GrimpBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_GrimpBody$class_object;

#endif	/* _JC_soot_grimp_GrimpBody_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/GrimpBody.h <==
// public class soot.grimp.GrimpBody

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class 81b257e12c028457 soot_grimp_GrimpBody
// @dep_class a93f9b2adf19105a soot_jimple_StmtBody
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_StmtBody

#include "soot/jimple/StmtBody.h"

#ifndef _JC_soot_grimp_GrimpBody_H_
#define _JC_soot_grimp_GrimpBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Body$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_grimp_GrimpBody$sub_refs	_jc_soot_grimp_GrimpBody$sub_refs;
typedef struct _jc_soot_grimp_GrimpBody$sub_nonrefs	_jc_soot_grimp_GrimpBody$sub_nonrefs;
typedef struct _jc_soot_grimp_GrimpBody$refs	_jc_soot_grimp_GrimpBody$refs;
typedef struct _jc_soot_grimp_GrimpBody$nonrefs	_jc_soot_grimp_GrimpBody$nonrefs;
typedef struct _jc_soot_grimp_GrimpBody$object	_jc_soot_grimp_GrimpBody$object;

typedef const struct _jc_soot_grimp_GrimpBody$vmethods	_jc_soot_grimp_GrimpBody$vmethods;
typedef const struct _jc_soot_grimp_GrimpBody$vtable	_jc_soot_grimp_GrimpBody$vtable;
typedef const struct _jc_soot_grimp_GrimpBody$vtype	_jc_soot_grimp_GrimpBody$vtype;

// Constructors
extern void _jc_soot_grimp_GrimpBody$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_grimp_GrimpBody$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern void _jc_soot_grimp_GrimpBody$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_grimp_GrimpBody$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_GrimpBody$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_GrimpBody$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_GrimpBody$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_GrimpBody$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_GrimpBody$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_GrimpBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_Body$vmethods	soot_Body;
	_jc_soot_jimple_StmtBody$vmethods	soot_jimple_StmtBody;
	_jc_soot_grimp_GrimpBody$vmethods	soot_grimp_GrimpBody;
};

// Vtype
struct _jc_soot_grimp_GrimpBody$vtype {
	_jc_type			type;
	_jc_soot_grimp_GrimpBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_GrimpBody$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_GrimpBody$refs {
    _jc_soot_grimp_GrimpBody$sub_refs	soot_grimp_GrimpBody;
    _jc_soot_jimple_StmtBody$sub_refs	soot_jimple_StmtBody;
    _jc_soot_Body$sub_refs	soot_Body;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_GrimpBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_GrimpBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_Body$sub_nonrefs	soot_Body;
    _jc_soot_jimple_StmtBody$sub_nonrefs	soot_jimple_StmtBody;
    _jc_soot_grimp_GrimpBody$sub_nonrefs	soot_grimp_GrimpBody;
};

// Object instance structure
struct _jc_soot_grimp_GrimpBody$object {
	_jc_soot_grimp_GrimpBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_GrimpBody$vtype	*vtype;
	_jc_soot_grimp_GrimpBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_GrimpBody$vtype _jc_soot_grimp_GrimpBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_GrimpBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_GrimpBody$class_object;

#endif	/* _JC_soot_grimp_GrimpBody_H_ */
